@@ -11,8 +11,7 @@ of the License, or (at your option) any later version.
 
 [cpscotti, roboscotti, scotti@ieee.org]
 
-Sincere thanks to No!No!No!Yes!@talk.maemo.org for adding some desired features that I "rejected" just for being lazy ....lol
-(nobody looks at the source code anyway)
+Sincere thanks to No!No!No!Yes!@talk.maemo.org for support for multiple lines
 For more info:
 http://talk.maemo.org/showthread.php?t=39177
 
@@ -345,13 +344,18 @@ void desktop_cmd_exec_write_settings (DesktopCmdExec *self, gboolean newAll, gbo
 	{
 //  		g_warning("records empty, filling with pre-loaded vals");
 		//records empty, filling with pre-loaded vals
-		self->priv->c_size = 4;
-		gchar * p_titles[] = { "Uptime:", "Battery(%):", "Battery(mAh):", "Boot Reason:", NULL};
+		self->priv->c_size = 9;
+		gchar * p_titles[] = { "Uptime:", "Battery(%):", "Battery(mAh):", "Boot Reason:", "Boot Count:", "External IP:", "Internal IP:", "Rootfs(%):", "Free Rootfs:", NULL};
 		gchar * p_commands[] = {
-		"uptime|cut -d\" \" -f3-|cut -d\",\" -f-1",
-		"hal-device | grep percen | awk '{print $3 \"%\"}'",
-		"hal-device | grep battery.reporting | awk -F. '{print $3}' | sort | awk '$1 == \"current\" { current = $3}; $1== \"design\" {print current \"/\" $3}'",
-		"cat /proc/bootreason", NULL};
+		"uptime|cut -d\" \" -f4-|sed 's/\\, *load.*//'",
+		"hal-device bme | awk -F\"[. ]\" '$5 == \"is_charging\" {chrg = $7}; $5 == \"percentage\" {perc = $7} END if (chrg == \"false\") {print perc \"%\"} else {print \"Chrg\"}'",
+		"hal-device bme | grep battery.reporting | awk -F. '{print $3}' | sort | awk '$1 == \"current\" { current = $3}; $1== \"design\" {print current \"/\" $3}'",
+		"cat /proc/bootreason",
+		"cat /var/lib/dsme/boot_count",
+		"wget -q -O - api.myiptest.com | awk -F \"\\\"\" '{print $4}'",
+		"/sbin/ifconfig | grep \"inet addr\" | awk -F: '{print $2}' | awk '{print $1}'",
+		"df | awk '$1 == \"rootfs\" {print $5}'",
+		"df -h | awk ' $1 == \"rootfs\" {print $4\"B\"}'", NULL};
 
 		//clean possible oldies
 		g_strfreev(self->priv->c_titles);
@@ -514,8 +518,9 @@ void desktop_cmd_exec_content_create (DesktopCmdExec *self)
 	
 	hildon_helper_set_logical_color (self->priv->cmdResult_lb, GTK_RC_FG, GTK_STATE_NORMAL, "ActiveTextColor");
 
-	gtk_misc_set_alignment (GTK_MISC (self->priv->cmdTitle_lb), 0, 0);//Changed Alignment to Top-Left //AP
-	gtk_misc_set_alignment (GTK_MISC (self->priv->cmdResult_lb), 0, 0);//Changed Alignment to Top-Left //AP
+	//Alignment!! (...., (left/right), (top/bottom))
+	gtk_misc_set_alignment (GTK_MISC (self->priv->cmdTitle_lb), 0, 0);
+	gtk_misc_set_alignment (GTK_MISC (self->priv->cmdResult_lb), 1, 1);
 
 	gtk_misc_set_padding (GTK_MISC (self->priv->cmdTitle_lb), HILDON_MARGIN_DEFAULT, HILDON_MARGIN_HALF);
 	gtk_misc_set_padding (GTK_MISC (self->priv->cmdResult_lb), HILDON_MARGIN_DEFAULT, HILDON_MARGIN_HALF);
@@ -842,6 +847,12 @@ void desktop_cmd_exec_settings (HDHomePluginItem *hitem, DesktopCmdExec *self)
 		gtk_container_add (GTK_CONTAINER (content_area), cmdSelector);
 		//END
 
+		GtkWidget *cmdHelpLabel = gtk_label_new ("");
+		gtk_label_set_markup (GTK_LABEL (cmdHelpLabel), "<small>(Add multiple widgets to your desktop to use more than one command)</small>");
+		gtk_misc_set_alignment (GTK_MISC (cmdHelpLabel), 0, 0);
+		gtk_label_set_line_wrap (GTK_LABEL (cmdHelpLabel), TRUE);
+		gtk_container_add (GTK_CONTAINER (content_area), cmdHelpLabel);
+
 		//BEGIN
 		//layout opts
 
